package com.yanzuoguang.dao;


/**
 * 数据基本操作接口
 * @author 颜佐光
 */
public interface BaseDao {

    /**
     * 创建数据,当不传入了主键时，则会自动生成主键，传入时不会生成。
     *
     * @param model 需要创建的数据
     * @return 创建的主键编号
     */
    String create(Object model);


    /**
     * 修改数据
     *
     * @param model 需要修改的数据
     * @return 删除的主键编号
     */
    String update(Object model);

    /**
     * 保存数据,有主键时修改，无主键时创建
     *
     * @param model 需要保存的数据
     * @return 保存的主键编号
     */
    String save(Object model);

    /**
     * 删除数据
     *
     * @param model 需要删除的数据
     * @return 删除的记录数量
     */
    int remove(Object model);

    /**
     * 加载数据
     *
     * @param model 加载数据的请求参数
     * @param cls   需要加载的数据的类型
     * @param <T>   返回数据的类型
     * @return 需要返回的数据
     */
    <T extends Object> T load(Object model, Class<T> cls);
}
